import 'dart:async';

import 'package:apex_flutter_plugin/apex_flutter_plugin.dart';
import 'package:apex_flutter_plugin/api/api.dart';
import 'package:apex_flutter_plugin/api/base_request.dart';
import 'package:apex_flutter_plugin/api/cancellation_token.dart';
import 'package:apex_flutter_plugin/api/config.dart';
import 'package:apex_flutter_plugin/api/request.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'constants.dart';

void main() {
  debugDefaultTargetPlatformOverride = TargetPlatform.fuchsia;
  runApp(MaterialApp(
    home: MyApp(),
  ));
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _fingerprint = 'Unknown';
  String _androidId = 'Unknown';
  String _hashUID = 'Unknown';

  @override
  void initState() {
    Api.shared.config = ApiConfig(
        "https://jsonplaceholder.typicode.com/posts/1",
        encrypt: false,
        debugMode: true,
        secretKey: Constants.CRYPTO_SECRET_KEY);

    super.initState();
    initPlatformState();
  }

  Future<void> initPlatformState() async {
    String fingerprint, androidId, hashUID;
    try {
      fingerprint = await ApexFlutterPlugin.fingerprint();
      androidId = await ApexFlutterPlugin.androidId();
      hashUID = await ApexFlutterPlugin.hashUID();
    } on PlatformException {
      fingerprint = 'Failed to get fingerprint.';
    }
    if (!mounted) return;

    setState(() {
      _fingerprint = fingerprint;
      _androidId = androidId;
      _hashUID = hashUID;
    });
  }

  String _text = "wtf";
  int _index = 0;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(_text + _index.toString()),
      ),
      body: Center(
        child: RaisedButton(
          onPressed: () {
            CancellationToken token = new CancellationToken();
            Api.shared
                .makeRequest(Request(null, method: Method.GET),
                    cancelToken: token)
                .then((response) {
              setState(() {
                _text = response.body;
              });
              token.cancel("cancel this");
            }).catchError((e) {
              if (e is OperationCanceledError) {
                print(e.toString());
              } else if (e is TimeoutException) {
                print(e.toString());
              } else {
                print(e.toString());
              }
            });
          },
          child: Text("FINGERPRINT" +
              _fingerprint +
              "\r\nandroidID" +
              _androidId.length.toString() +
              "\r\nhashUID" +
              _hashUID),
        ),
      ),
    );
  }
}
